@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,68 +33,13 @@
 
 #endif // !defined(__HIPCC_RTC__)
 
+#include "vector.hpp"
 #include "utility/forward.hpp"
 #include "utility/sequence.hpp"
 #include "utils.hpp"
 
 namespace rocwmma
 {
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator+(non_native_vector_base<VecT, Rank> const& x, U y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} += non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator+(U x, non_native_vector_base<VecT, Rank> const& y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} += non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator-(non_native_vector_base<VecT, Rank> const& x, U y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} -= non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator-(U x, const non_native_vector_base<VecT, Rank>& y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} -= non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator*(const non_native_vector_base<VecT, Rank>& x, U y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} *= non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator*(U x, const non_native_vector_base<VecT, Rank>& y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} *= non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator/(const non_native_vector_base<VecT, Rank>& x, U y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} /= non_native_vector_base<VecT, Rank>{y};
-    }
-
-    template <typename VecT, unsigned int Rank, typename U>
-    ROCWMMA_HOST_DEVICE inline constexpr non_native_vector_base<VecT, Rank>
-        operator/(U x, const non_native_vector_base<VecT, Rank>& y) noexcept
-    {
-        return non_native_vector_base<VecT, Rank>{x} /= non_native_vector_base<VecT, Rank>{y};
-    }
-
     namespace detail
     {
         template <typename VecT, size_t... Indices>
@@ -104,18 +49,20 @@ namespace rocwmma
         }
     }
 
-    template <typename VecT>
-    constexpr static auto pop_right(VecT&& t)
+    template <uint32_t Count = 1u, typename VecT>
+    constexpr static auto pop_back(VecT&& t)
     {
-        return detail::copy_impl(forward<VecT>(t),
-                                 make_index_sequence<VecTraits<decay_t<VecT>>::size() - 1>{});
+        return detail::copy_impl(
+            forward<VecT>(t),
+            make_offset_index_sequence<VecTraits<decay_t<VecT>>::size() - Count>());
     }
 
-    template <typename VecT>
-    constexpr static auto pop_left(VecT&& t)
+    template <uint32_t Count = 1u, typename VecT>
+    constexpr static auto pop_front(VecT&& t)
     {
-        auto pop_front = [](auto front, auto... rest) { return make_vector(rest...); };
-        return apply(pop_front, forward<VecT>(t));
+        return detail::copy_impl(
+            forward<VecT>(t),
+            make_offset_index_sequence<VecTraits<decay_t<VecT>>::size() - Count, Count>());
     }
 
     template <typename VecT>
@@ -218,17 +165,26 @@ namespace rocwmma
         constexpr static inline decltype(auto)
             inflate_coord_right_impl(Coord1d&& flatCoord, VecT&& dims, index_sequence<Indices...>)
         {
-            auto inflate = [](auto&& c, auto&& d, auto& div, bool last) {
-                auto result = (last ? (c / div) : (c / div % d));
-                div *= d;
-                return result;
+            auto inflate = [](auto&& c, auto&& d, auto& div, auto&& is_last) {
+                if constexpr((bool)decay_t<decltype(is_last)>::value == true)
+                {
+                    auto result = c / div;
+                    div *= d;
+                    return result;
+                }
+                else
+                {
+                    auto result = c / div % d;
+                    div *= d;
+                    return result;
+                }
             };
 
             auto div = decay_t<Coord1d>{1};
             return make_vector(inflate(forward<Coord1d>(flatCoord),
                                        get<Indices>(forward<VecT>(dims)),
                                        forward<decltype(div)&>(div),
-                                       Indices == sizeof...(Indices) - 1)...);
+                                       I<Indices == sizeof...(Indices) - 1>{})...);
         }
     }
 
@@ -247,10 +203,19 @@ namespace rocwmma
         constexpr static inline decltype(auto)
             inflate_coord_left_impl(Coord1d&& flatCoord, VecT&& dims, index_sequence<Indices...>)
         {
-            auto inflate = [](auto&& c, auto&& d, auto& div, bool last) {
-                auto result = (last ? (c / div) : (c / div % d));
-                div *= d;
-                return result;
+            auto inflate = [](auto&& c, auto&& d, auto& div, auto&& is_last) {
+                if constexpr((bool)decay_t<decltype(is_last)>::value == true)
+                {
+                    auto result = c / div;
+                    div *= d;
+                    return result;
+                }
+                else
+                {
+                    auto result = c / div % d;
+                    div *= d;
+                    return result;
+                }
             };
 
             auto div = decay_t<Coord1d>{1};
@@ -258,7 +223,7 @@ namespace rocwmma
                 inflate(forward<Coord1d>(flatCoord),
                         get<VecTraits<decay_t<VecT>>::size() - 1 - Indices>(forward<VecT>(dims)),
                         forward<decltype(div)&>(div),
-                        Indices == sizeof...(Indices) - 1)...));
+                        I<Indices == sizeof...(Indices) - 1>{})...));
         }
     }
 
@@ -273,29 +238,33 @@ namespace rocwmma
 
     namespace detail
     {
-        template <typename Vec0, typename Vec1, size_t... Indices>
+        template <typename VecT0, typename VecT1, size_t... Indices>
         constexpr static inline decltype(auto)
-            to_matrix_space_impl(Vec0&& strides, Vec1&& strideSpace, index_sequence<Indices...>)
+            to_matrix_space_impl(VecT0&& strideCoord, VecT1&& strides, index_sequence<Indices...>)
         {
-            static_assert(VecTraits<decay_t<Vec0>>::size() == sizeof...(Indices)
-                              && VecTraits<decay_t<Vec1>>::size() == sizeof...(Indices),
-                          "strides and strideSpace vectors must be the same size");
+            static_assert(VecTraits<decay_t<VecT0>>::size() == sizeof...(Indices)
+                              && VecTraits<decay_t<VecT1>>::size() == sizeof...(Indices),
+                          "strideCoord and strides vectors must be the same size");
 
-            auto inflate = [](auto&& stride, auto&& dim) { return stride * dim; };
+            auto matrix_space_offset
+                = [](auto&& component, auto&& stride) { return component * stride; };
 
-            return (inflate(get<Indices>(forward<Vec0>(strides)),
-                            get<Indices>(forward<Vec1>(strideSpace)))
+            // Calculate a final matrix-space offset by accumulating
+            // each stride coordinate component multiplied by their respective stride:
+            // result = Sum(strideCoord[0]* strides[0] + ... + strideCoord[N-1] * strides[N-1])
+            return (matrix_space_offset(get<Indices>(forward<VecT0>(strideCoord)),
+                                        get<Indices>(forward<VecT1>(strides)))
                     + ...);
         }
     }
 
-    template <typename Vec0, typename Vec1>
-    constexpr static inline decltype(auto) to_matrix_space(Vec0&& strides, Vec1&& strideSpace)
+    template <typename VecT0, typename VecT1>
+    constexpr static inline decltype(auto) to_matrix_space(VecT0&& strideCoord, VecT1&& strides)
     {
         return detail::to_matrix_space_impl(
-            forward<Vec0>(strides),
-            forward<Vec1>(strideSpace),
-            make_index_sequence<VecTraits<decay_t<Vec0>>::size()>{});
+            forward<VecT0>(strideCoord),
+            forward<VecT1>(strides),
+            make_index_sequence<VecTraits<decay_t<VecT0>>::size()>{});
     }
 
 #if !defined(__HIPCC_RTC__)
