@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,8 +33,12 @@
 namespace rocwmma
 {
 
-    template <typename DataT, uint TILE_DIM, typename LdsMapping>
-    __global__ void __launch_bounds__(128, 1) dlrmDotFwdLds(const DataT* __restrict input,
+    template <typename DataT,
+              uint TILE_DIM,
+              typename LdsMapping,
+              uint32_t TBlockX,
+              uint32_t TBlockY>
+    __global__ void __launch_bounds__(TBlockX, TBlockY) dlrmDotFwdLds(const DataT* __restrict input,
                                                             DataT* __restrict output,
                                                             float32_t* acc,
                                                             uint       m,
@@ -65,6 +69,8 @@ namespace rocwmma
                                           col_major,
                                           row_major,
                                           LdsMapping,
+                                          TBlockX,
+                                          TBlockY,
                                           1,
                                           1>;
 
