@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,10 +38,7 @@ namespace rocwmma
 
     namespace CooperativeGemm
     {
-        template <typename GlobalMapping,
-                  typename LdsMapping,
-                  typename CoopSchedulerA,
-                  typename CoopSchedulerB>
+        template <typename GlobalMapping, typename LdsMapping>
         struct GemmDriver
         {
             // Global fragment types
@@ -65,12 +62,10 @@ namespace rocwmma
             using MappingUtil = GetMappingUtil_t<FragT>;
 
             template <typename FragT>
-            using GetIOTraitsFragA =
-                typename GetCoopIOConfig_t<FragT, CoopSchedulerA::waveCount()>::IOTraits;
+            using GetIOTraitsFragA = typename GetIOConfig_t<FragT>::IOTraits;
 
             template <typename FragT>
-            using GetIOTraitsFragB =
-                typename GetCoopIOConfig_t<FragT, CoopSchedulerB::waveCount()>::IOTraits;
+            using GetIOTraitsFragB = typename GetIOConfig_t<FragT>::IOTraits;
 
             // Ensure that splitCounts are the same on both sides of
             // global fetch and local writes to match fragment data locality.
@@ -238,6 +233,8 @@ namespace rocwmma
 
             template <int32_t lgkmcnt = 0>
             __device__ static inline void lds_mem_barrier();
+
+            __device__ static inline void scheduleKLoop();
         };
 
     } // namespace CooperativeGemm
