@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -79,6 +79,14 @@ namespace rocwmma
 
 } // namespace rocwmma
 
+TEST(VectorTest, VectorHostTest)
+{
+    auto result = rocwmma::vectorHostTest<float, 8>();
+    EXPECT_TRUE(result);
+    result = rocwmma::vectorHostTest<int, 8>();
+    EXPECT_TRUE(result);
+}
+
 // Test suite for unique parameterization
 class VectorTest : public rocwmma::UnitTest
 {
