@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,34 +31,17 @@
 
 namespace rocwmma
 {
-    template <typename DataT, uint32_t VecSize>
-    ROCWMMA_DEVICE static inline DataT get(VecT<DataT, VecSize> const& v, uint32_t idx)
-    {
-        return v.data[idx];
-    }
-
-    template <typename DataT, uint32_t VecSize, uint32_t Start = 0>
-    ROCWMMA_DEVICE static inline auto generateSeqVec()
-    {
-        auto buildSeq = [](auto&& idx) {
-            constexpr auto Index = std::decay_t<decltype(idx)>::value;
-            return static_cast<DataT>(Index) + static_cast<DataT>(Start);
-        };
-
-        return vector_generator<DataT, VecSize>()(buildSeq);
-    }
-
     template <typename DataT, uint32_t VecSize>
     ROCWMMA_DEVICE static inline bool vectorGeneratorTestBasic()
     {
         bool err = false;
 
-        auto res = generateSeqVec<DataT, VecSize>();
+        auto res = make_vector_sequence<DataT, VecSize>();
 
-        for(uint32_t i = 0; i < VecSize; i++)
-        {
-            err |= (get(res, i) != static_cast<DataT>(i));
-        }
+        static_for<0, VecSize, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != static_cast<DataT>(i));
+        });
 
         return err;
     }
@@ -73,15 +56,15 @@ namespace rocwmma
             return get<Index>(v0) + get<Index>(v1);
         };
 
-        auto v0 = VecT<DataT, VecSize>{static_cast<DataT>(1.0f)};
-        auto v1 = VecT<DataT, VecSize>{static_cast<DataT>(2.0f)};
+        auto v0 = make_vector<DataT, VecSize>(static_cast<DataT>(1.0f));
+        auto v1 = make_vector<DataT, VecSize>(static_cast<DataT>(2.0f));
 
         auto res = vector_generator<DataT, VecSize>()(sum, v0, v1);
 
-        for(uint32_t i = 0; i < VecSize; i++)
-        {
-            err |= (get(res, i) != (static_cast<DataT>(1.0f) + static_cast<DataT>(2.0f)));
-        }
+        static_for<0, VecSize, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != (static_cast<DataT>(1.0f) + static_cast<DataT>(2.0f)));
+        });
 
         return err;
     }
@@ -91,16 +74,16 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = extractEven(v);
 
         // Handle the general case
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize / 2; i++)
-            {
-                err |= (get(res, i) != static_cast<DataT>(i * 2));
-            }
+            static_for<0, VecSize / 2, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                err |= (get<i>(res) != static_cast<DataT>(i * 2));
+            });
         }
         // Handle case where VecSize == 1
         else
@@ -116,16 +99,16 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = extractOdd(v);
 
         // Handle general case
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize / 2; i++)
-            {
-                err |= (get(res, i) != static_cast<DataT>(i * 2 + 1));
-            }
+            static_for<0, VecSize / 2, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                err |= (get<i>(res) != static_cast<DataT>(i * 2 + 1));
+            });
         }
         // Handle case where VecSize == 1
         else
@@ -143,23 +126,23 @@ namespace rocwmma
         using PackTraits = typename PackUtil::Traits;
         bool err         = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = reorderEvenOdd(v);
 
         // Handle general case
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize; i++)
-            {
-                if(i < VecSize / 2)
+            static_for<0, VecSize, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                if constexpr(i < VecSize / 2)
                 {
-                    err |= (get(res, i) != static_cast<DataT>(i * 2));
+                    err |= (get<i>(res) != static_cast<DataT>(i * 2));
                 }
                 else
                 {
-                    err |= (get(res, i) != static_cast<DataT>((i - VecSize / 2) * 2 + 1));
+                    err |= (get<i>(res) != static_cast<DataT>((i - VecSize / 2) * 2 + 1));
                 }
-            }
+            });
         }
         // Handle case where VecSize == 1
         else
@@ -177,23 +160,23 @@ namespace rocwmma
         using PackTraits = typename PackUtil::Traits;
         bool err         = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = reorderOddEven(v);
 
         // Handle general case
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize; i++)
-            {
-                if(i < VecSize / 2)
+            static_for<0, VecSize, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                if constexpr(i < VecSize / 2)
                 {
-                    err |= (get(res, i) != static_cast<DataT>(i * 2 + 1));
+                    err |= (get<i>(res) != static_cast<DataT>(i * 2 + 1));
                 }
                 else
                 {
-                    err |= (get(res, i) != static_cast<DataT>((i - VecSize / 2) * 2));
+                    err |= (get<i>(res) != static_cast<DataT>((i - VecSize / 2) * 2));
                 }
-            }
+            });
         }
         // Handle case where VecSize == 1
         else
@@ -209,15 +192,15 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = extractLo(v);
 
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize / 2; i++)
-            {
-                err |= (get(res, i) != static_cast<DataT>(i));
-            }
+            static_for<0, VecSize / 2, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                err |= (get<i>(res) != static_cast<DataT>(i));
+            });
         }
         else
         {
@@ -232,15 +215,15 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = extractHi(v);
 
         if constexpr(VecSize > 1)
         {
-            for(uint32_t i = 0; i < VecSize / 2; i++)
-            {
-                err |= (get(res, i) != static_cast<DataT>(i + VecSize / 2));
-            }
+            static_for<0, VecSize / 2, 1>([&](auto&& Idx) {
+                constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+                err |= (get<i>(res) != static_cast<DataT>(i + VecSize / 2));
+            });
         }
         else
         {
@@ -255,13 +238,13 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v   = generateSeqVec<DataT, VecSize>();
+        auto v   = make_vector_sequence<DataT, VecSize>();
         auto res = concat(v, v);
 
-        for(uint32_t i = 0; i < VecSize * 2; i++)
-        {
-            err |= (get(res, i) != static_cast<DataT>(i % VecSize));
-        }
+        static_for<0, VecSize * 2, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != static_cast<DataT>(i % VecSize));
+        });
 
         return err;
     }
@@ -273,14 +256,14 @@ namespace rocwmma
         using PackTraits = typename PackUtil::Traits;
         bool err         = false;
 
-        auto v0  = generateSeqVec<DataT, VecSize>();
-        auto v1  = generateSeqVec<DataT, VecSize, VecSize>();
+        auto v0  = make_vector_sequence<DataT, VecSize>();
+        auto v1  = make_vector_sequence<DataT, VecSize, VecSize>();
         auto res = zip(v0, v1);
 
-        for(uint32_t i = 0; i < VecSize; i++)
-        {
-            err |= (get(res, i) != static_cast<DataT>(i + VecSize * (i & 1)));
-        }
+        static_for<0, VecSize, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != static_cast<DataT>(i + VecSize * (i & 1)));
+        });
 
         return err;
     }
@@ -290,15 +273,15 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v0  = generateSeqVec<DataT, VecSize>();
-        auto v1  = generateSeqVec<DataT, VecSize, VecSize>();
+        auto v0  = make_vector_sequence<DataT, VecSize>();
+        auto v1  = make_vector_sequence<DataT, VecSize, VecSize>();
         auto res = unpackLo(v0, v1);
 
         // 0, VecSize , 1, VecSize + 1, ...
-        for(uint32_t i = 0; i < VecSize; i++)
-        {
-            err |= (get(res, i) != static_cast<DataT>(i / 2 + VecSize * (i & 1)));
-        }
+        static_for<0, VecSize, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != static_cast<DataT>(i / 2 + VecSize * (i & 1)));
+        });
 
         return err;
     }
@@ -308,15 +291,15 @@ namespace rocwmma
     {
         bool err = false;
 
-        auto v0  = generateSeqVec<DataT, VecSize>();
-        auto v1  = generateSeqVec<DataT, VecSize, VecSize>();
+        auto v0  = make_vector_sequence<DataT, VecSize>();
+        auto v1  = make_vector_sequence<DataT, VecSize, VecSize>();
         auto res = unpackHi(v0, v1);
 
         // VecSize / 2, VecSize / 2 + VecSize , VecSize / 2 + 1, VecSize / 2 + VecSize + 1, ...
-        for(uint32_t i = 0; i < VecSize; i++)
-        {
-            err |= (get(res, i) != static_cast<DataT>(VecSize / 2 + i / 2 + VecSize * (i & 1)));
-        }
+        static_for<0, VecSize, 1>([&](auto&& Idx) {
+            constexpr uint32_t i = decay_t<decltype(Idx)>::value;
+            err |= (get<i>(res) != static_cast<DataT>(VecSize / 2 + i / 2 + VecSize * (i & 1)));
+        });
 
         return err;
     }
